@@ -71,14 +71,14 @@ _previous_executed_sql = ""
 has_passed_variables = False
 passed_variables = {}
 
-def configure_log(configuration_path):
+def configure_log(configuration_path=None):
     """Configures the logging that will be performed for any data related execution on the snowflake connection.
         The log file is named 'snowflake_python_connector.log' by default.
 
         configuration_path
             The configuration path of the file that contains all the settings desired for the logging.
     """
-    if configure_log : 
+    if configuration_path: 
         logging.config.fileConfig(configuration_path)
     else :
         logging.basicConfig(
@@ -231,9 +231,9 @@ def expandvar(str):
 
 opened_connections = []
 
-def log_on(user=None, password=None, account=None, database=None, warehouse=None, role=None, login_timeout=10):
-    """Logs on the snowflake database with the credentials, database, role and 
-    warehouse passed parameters.
+def log_on(user=None, password=None, account=None, database=None, warehouse=None, role=None, login_timeout=10, authenticator=None):
+    """Logs on the snowflake database with the credentials, database, warehouse,
+    role, login_timeout and authenticator passed parameters.
 
         user
             The user of the database
@@ -249,11 +249,12 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
             The maximum timeout before giving error if the connection is taking too
             long to connect
         authenticator
-            The authenticator to use.
+            The authenticator supported value to use like SNOWFLAKE, EXTERNALBROWSER,
+            SNOWFLAKE_JWT or OAUTH
     """
     global error_code
     global opened_connections
-    log("arguments: ",  sys.argv)
+    log(f"arguments: {sys.argv}")
     # exclude arguments passed inline to the script
     args = [item for item in sys.argv if not item.startswith("--param-")]
     if (user is None):
@@ -268,13 +269,14 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
         warehouse = get_from_vars_or_args_or_environment(5, "SNOW_WAREHOUSE", passed_variables, args)
     if (role is None):
         role = get_from_vars_or_args_or_environment(6, "SNOW_ROLE", passed_variables, args)
+    if (authenticator is None):
+        authenticator = get_from_vars_or_args_or_environment(7, "SNOW_AUTHENTICATOR", passed_variables, args)
     query_tag = passed_variables.get("SNOW_QUERYTAG", None)
     if (query_tag is None):
         query_tag = getenv("SNOW_QUERYTAG", None)
     if query_tag is None:
         frm = inspect.stack()[1]
         query_tag = path.basename(frm.filename)
-    authenticator = getenv("SNOW_AUTHENTICATOR", None)
     c = None
     try:
 
@@ -436,7 +438,7 @@ def _print_result_set(cur):
             log(','.join([str(val) for val in row]))
         log("")
     else:
-        log(">>>>>> Exporting to ", Export.expandedfilename)
+        log(f">>>>>> Exporting to {Export.expandedfilename}")
         reportdir = path.dirname(Export.expandedfilename)
         makedirs(reportdir, exist_ok=True)
         with open(Export.expandedfilename, 'a') as f:
